# Tests for ob_reduce_deps()
#
# Copyright (C) 2012, 2018 Patrick McDermott
#
# This file is part of opkbuild.
#
# opkbuild is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# opkbuild is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with opkbuild.  If not, see <http://www.gnu.org/licenses/>.

set -eu

. "${TOP_SRCDIR}/tests/aux/tap-functions.sh"
. "${TOP_BUILDDIR}/lib/libopkbuild.${SHSOEXT}.${LIBOPKBUILD_SHSOVERSION}"

plan_ 11

# Normal and union AND-lists.

command_ok_ \
	'NORMAL LIST "foo, bar"' -- \
	[ x"$(ob_reduce_deps \
		-a 'amd64-linux-glibc' \
		'foo, bar' \
	)" = \
		x'foo, bar' \
	]

command_ok_ \
	'NORMAL LIST "foo,bar"' -- \
	[ x"$(ob_reduce_deps \
		-a 'amd64-linux-glibc' \
		'foo,bar' \
	)" = \
		x'foo, bar' \
	]

command_ok_ \
	'NORMAL LIST "foo,   bar"' -- \
	[ x"$(ob_reduce_deps \
		-a 'amd64-linux-glibc' \
		'foo,   bar' \
	)" = \
		x'foo, bar' \
	]

command_ok_ \
	'UNION LIST "foo, bar"' -- \
	[ x"$(ob_reduce_deps \
		-u \
		-a 'amd64-linux-glibc' \
		'foo, bar' \
	)" = \
		x'foo, bar' \
	]

command_ok_ \
	'UNION LIST "foo,bar"' -- \
	[ x"$(ob_reduce_deps \
		-u \
		-a 'amd64-linux-glibc' \
		'foo,bar' \
	)" = \
		x'foo, bar' \
	]

command_ok_ \
	'UNION LIST "foo,   bar"' -- \
	[ x"$(ob_reduce_deps \
		-u \
		-a 'amd64-linux-glibc' \
		'foo,   bar' \
	)" = \
		x'foo, bar' \
	]

# Normal OR-lists.

command_ok_ \
	'NORMAL LIST "foo | bar"' -- \
	[ x"$(ob_reduce_deps \
		-a 'amd64-linux-glibc' \
		'foo | bar' \
	)" = \
		x'foo | bar' \
	]

command_ok_ \
	'NORMAL LIST "foo|bar"' -- \
	[ x"$(ob_reduce_deps \
		-a 'amd64-linux-glibc' \
		'foo|bar' \
	)" = \
		x'foo | bar' \
	]

command_ok_ \
	'NORMAL LIST "foo   |   bar"' -- \
	[ x"$(ob_reduce_deps \
		-a 'amd64-linux-glibc' \
		'foo   |   bar' \
	)" = \
		x'foo | bar' \
	]

# Normal and union AND-lists with arch specs.

command_ok_ \
	'NORMAL LIST "foo [amd64-linux-glibc], bar [!amd64-linux-glibc]"' -- \
	[ x"$(ob_reduce_deps \
		-a 'amd64-linux-glibc' \
		'foo [amd64-linux-glibc], bar [!amd64-linux-glibc]' \
	)" = \
		x'foo' \
	]

command_ok_ \
	'UNION LIST "foo [amd64-linux-glibc], bar [!amd64-linux-glibc]"' -- \
	[ x"$(ob_reduce_deps \
		-u \
		-a 'amd64-linux-glibc' \
		'foo [amd64-linux-glibc], bar [!amd64-linux-glibc]' \
	)" = \
		x'foo' \
	]
